### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v1.3.3](https://github.com/RhetTbull/osxmetadata/compare/v1.3.2...v1.3.3)

> 18 November 2023

- Updated dependencies, #102 [`#103`](https://github.com/RhetTbull/osxmetadata/pull/103)
- Updated README_DEV.md for docs [skip ci] [`3ce16fc`](https://github.com/RhetTbull/osxmetadata/commit/3ce16fcb4c1426842397d0b0b6365140f5a81974)
- Version bump [`279b55f`](https://github.com/RhetTbull/osxmetadata/commit/279b55fcd8b4cbd2a21f3cc553c6f1baeabdc6a5)

#### [v1.3.2](https://github.com/RhetTbull/osxmetadata/compare/v1.3.1...v1.3.2)

> 21 October 2023

- Added support for python3.12 [`#101`](https://github.com/RhetTbull/osxmetadata/pull/101)
- Added notes on changelog [`58ee9a9`](https://github.com/RhetTbull/osxmetadata/commit/58ee9a9cd2710c70c1fa64ee842accea50ebf7d4)
- Version bump [`fd99a3e`](https://github.com/RhetTbull/osxmetadata/commit/fd99a3eaae41a6a8de63bb91a0fdd75c51628753)

#### [v1.3.1](https://github.com/RhetTbull/osxmetadata/compare/v1.3.0...v1.3.1)

> 14 September 2023

- Release 1.3.1 to fix for python 3.11 #98 [`#100`](https://github.com/RhetTbull/osxmetadata/pull/100)
- Updated dependencies for #98 [`#99`](https://github.com/RhetTbull/osxmetadata/pull/99)
- Version bump [`648e821`](https://github.com/RhetTbull/osxmetadata/commit/648e821f740190d2015042c1cce6d4528d33a6bc)

#### [v1.3.0](https://github.com/RhetTbull/osxmetadata/compare/v1.2.2...v1.3.0)

> 19 April 2023

- docs: add luckman212 as a contributor for code [`#87`](https://github.com/RhetTbull/osxmetadata/pull/87)
- Fix for #95 kMDItemContentTypeTree serialization [`72f7d0f`](https://github.com/RhetTbull/osxmetadata/commit/72f7d0f80cd06f2ffe85858a8c9a38d2f1968b64)
- docs: update .all-contributorsrc [skip ci] [`995529b`](https://github.com/RhetTbull/osxmetadata/commit/995529b7d0afe6650851f7bafb7270677ed2b698)
- docs: update README.md [skip ci] [`6300da0`](https://github.com/RhetTbull/osxmetadata/commit/6300da0ba93a6473760d2bf08e5988ef2b2c0fd7)

#### [v1.2.2](https://github.com/RhetTbull/osxmetadata/compare/v1.2.1...v1.2.2)

> 16 November 2022

- Additional fix for #83, kMDItemKeywords as comma delimited string [`48ff7a7`](https://github.com/RhetTbull/osxmetadata/commit/48ff7a7136affbf00722506b7e5f378811325ca2)
- Fix for kMDItemKeywords as comma delimited string, #83 [`c7ca9d0`](https://github.com/RhetTbull/osxmetadata/commit/c7ca9d055c7178367def28cccd0d814c8444d7e9)

#### [v1.2.1](https://github.com/RhetTbull/osxmetadata/compare/v1.2.0...v1.2.1)

> 16 November 2022

- Bug k md item keywords string value 83 [`#86`](https://github.com/RhetTbull/osxmetadata/pull/86)
- docs: add luckman212 as a contributor for bug [`#85`](https://github.com/RhetTbull/osxmetadata/pull/85)
- Fix for kMDItemKeywords as comma delimited string, #83, #84 [`2bccca2`](https://github.com/RhetTbull/osxmetadata/commit/2bccca2f6cc81c7b3070dabbf1733f3a8e4a87ab)
- updated README [`20ef4ad`](https://github.com/RhetTbull/osxmetadata/commit/20ef4adde0307b94a902dd407fb894b0b44f5e0d)
- docs: update .all-contributorsrc [skip ci] [`c7e008a`](https://github.com/RhetTbull/osxmetadata/commit/c7e008a8adc7f9e36b1fbff259e25ee298899cf7)
- Version bump [`cbfbdaa`](https://github.com/RhetTbull/osxmetadata/commit/cbfbdaa866acea5eecc551d295a76bc6435a3372)
- Update README.md [`243081f`](https://github.com/RhetTbull/osxmetadata/commit/243081fa3a3d9365fa9af29fee4348032c843e1d)

#### [v1.2.0](https://github.com/RhetTbull/osxmetadata/compare/v1.1.0...v1.2.0)

> 12 November 2022

- Python 3.11 [`#79`](https://github.com/RhetTbull/osxmetadata/pull/79)
- Updated dependencies for python 3.11 [`dff883d`](https://github.com/RhetTbull/osxmetadata/commit/dff883df2f0ff8f03c644e7308b55ad374057d4a)
- Version bump [`11eba39`](https://github.com/RhetTbull/osxmetadata/commit/11eba39dbc3f5ab468c8c7a2b3743dd7eb131218)

#### [v1.1.0](https://github.com/RhetTbull/osxmetadata/compare/v1.0.0...v1.1.0)

> 10 November 2022

- Removed null values from backup JSON #75 [`#77`](https://github.com/RhetTbull/osxmetadata/pull/77)
- docs: add porg as a contributor for bug, and ideas [`#72`](https://github.com/RhetTbull/osxmetadata/pull/72)
- docs: add jakewilliami as a contributor for ideas [`#65`](https://github.com/RhetTbull/osxmetadata/pull/65)
- docs: add nk9 as a contributor for bug [`#64`](https://github.com/RhetTbull/osxmetadata/pull/64)
- Code cleanup [`cbda1cd`](https://github.com/RhetTbull/osxmetadata/commit/cbda1cda90a4feeb5a090cb96aaa188b33b87007)
- Release 1.1.0, remove null values from JSON file [`226679f`](https://github.com/RhetTbull/osxmetadata/commit/226679f2cdea6668a6399d4c844220e6ec1b2f68)
- Update README.md, code clean up [`f0aea90`](https://github.com/RhetTbull/osxmetadata/commit/f0aea90dc088eb1af5bfa7df3595e3d09e73b101)
- Updated tests with snooze for GH Actions [`b2d31d6`](https://github.com/RhetTbull/osxmetadata/commit/b2d31d618313a69999fc4284f7aa61cb7639610e)
- Updated tests with snooze for GH Actions [`de053cf`](https://github.com/RhetTbull/osxmetadata/commit/de053cfe839cf743853d81488c558b44ee123df8)

### [v1.0.0](https://github.com/RhetTbull/osxmetadata/compare/v0.99.38...v1.0.0)

> 7 October 2022

- Rewrite [`#63`](https://github.com/RhetTbull/osxmetadata/pull/63)
- docs: add porg as a contributor for bug [`#59`](https://github.com/RhetTbull/osxmetadata/pull/59)
- Added first set of tests [`153acc3`](https://github.com/RhetTbull/osxmetadata/commit/153acc3dd7ecca488ce32efb7286ded5ad309b3a)
- Basic implementation and reading Finder tags [`af07d99`](https://github.com/RhetTbull/osxmetadata/commit/af07d99d3ea2f6bcb960ab02199411c63762cfd7)
- Moved from setup.py to poetry & pyproject.toml [`42b887b`](https://github.com/RhetTbull/osxmetadata/commit/42b887b11bcc488c8b50cc988571e36f7bfcf5b0)
- Updated README with doctests [`0c087ad`](https://github.com/RhetTbull/osxmetadata/commit/0c087ad462333fc5c4ed83376506215d1770224c)
- Updated tests, build scripts [`0486429`](https://github.com/RhetTbull/osxmetadata/commit/04864295dc6ce56314985f4b7ebe0470cfa6832a)

#### [v0.99.38](https://github.com/RhetTbull/osxmetadata/compare/v0.99.37...v0.99.38)

> 17 July 2022

- Fixed backup database to be conformant JSON, #56 [`a01c4bb`](https://github.com/RhetTbull/osxmetadata/commit/a01c4bba50cfee5bcd799481ed4e43977c3410da)
- Added doit build script [`5e874ef`](https://github.com/RhetTbull/osxmetadata/commit/5e874efd846c73e55ffcc1a1e0cb1a258acb7145)
- Fixed backup database to be conformant JSON, #56 [`255a128`](https://github.com/RhetTbull/osxmetadata/commit/255a12889f14dc81a14ce32d4a3dc6d232a44341)

#### [v0.99.37](https://github.com/RhetTbull/osxmetadata/compare/v0.99.36...v0.99.37)

> 25 November 2021

- Updated dependencies for pyobjc 8.0 [`564fb04`](https://github.com/RhetTbull/osxmetadata/commit/564fb048d8362d6613dd0a0a063394af9009314b)

#### [v0.99.36](https://github.com/RhetTbull/osxmetadata/compare/v0.99.34...v0.99.36)

> 4 November 2021

- Dependency update for Monterey [`040b4ee`](https://github.com/RhetTbull/osxmetadata/commit/040b4eeb10b80dfb840ae0940e5e38a43b58a6ef)
- Dependency update for Monterey [`bb6c4b6`](https://github.com/RhetTbull/osxmetadata/commit/bb6c4b6e87c52a97d922dcb4c7000a6135b774fd)

#### [v0.99.34](https://github.com/RhetTbull/osxmetadata/compare/v0.99.33...v0.99.34)

> 30 October 2021

- Fix for missing plist file on Monterey [`df23b8e`](https://github.com/RhetTbull/osxmetadata/commit/df23b8e8f1f45397e992b7beab400a3238c81b0d)

#### [v0.99.33](https://github.com/RhetTbull/osxmetadata/compare/v0.99.31...v0.99.33)

> 29 August 2021

- Updated dependencies [`520d9f4`](https://github.com/RhetTbull/osxmetadata/commit/520d9f4ebfa75260c7051116a496ebeb076b8c8d)
- Version bump [`3123b50`](https://github.com/RhetTbull/osxmetadata/commit/3123b5049505437241fabde4813f1c7eeb2663d6)

#### [v0.99.31](https://github.com/RhetTbull/osxmetadata/compare/v0.99.30...v0.99.31)

> 1 August 2021

- Fixed None value for osxphotos.metadata:detected_text [`9b7fa79`](https://github.com/RhetTbull/osxmetadata/commit/9b7fa79b1df165cec9ed385014b49ef4f8440aae)

#### [v0.99.30](https://github.com/RhetTbull/osxmetadata/compare/v0.99.28...v0.99.30)

> 1 August 2021

- Fixed str output for osxphotos.metadata [`34a734e`](https://github.com/RhetTbull/osxmetadata/commit/34a734e7cfbf8c2317cea84ac20333dcd023141a)
- Version bump [`6e8e11b`](https://github.com/RhetTbull/osxmetadata/commit/6e8e11baaa38c89f718177008758b9462b18838e)

#### [v0.99.28](https://github.com/RhetTbull/osxmetadata/compare/v0.99.26...v0.99.28)

> 31 July 2021

- Added support for osxphotos metadata [`373b193`](https://github.com/RhetTbull/osxmetadata/commit/373b193ddc4f78aab3865cbf721e4aadd6dd155a)

#### [v0.99.26](https://github.com/RhetTbull/osxmetadata/compare/v0.99.25...v0.99.26)

> 25 July 2021

- Updated pyobjc version requirements [`01adc53`](https://github.com/RhetTbull/osxmetadata/commit/01adc5307b212f322c491be3ef99956ea10f9538)

#### [v0.99.25](https://github.com/RhetTbull/osxmetadata/compare/v0.99.24...v0.99.25)

> 15 July 2021

- Fixed restore bug with finderinfo [`6f369a4`](https://github.com/RhetTbull/osxmetadata/commit/6f369a4d8416fea9309b99d838be3813a4df0424)

#### [v0.99.24](https://github.com/RhetTbull/osxmetadata/compare/v0.99.23...v0.99.24)

> 15 July 2021

- Added subject and title, closes #45 [`#45`](https://github.com/RhetTbull/osxmetadata/issues/45)
- Updated README.md with install instructions [`5ce8876`](https://github.com/RhetTbull/osxmetadata/commit/5ce887639a3bd263ee490d4b861fc34a698a734f)

#### [v0.99.23](https://github.com/RhetTbull/osxmetadata/compare/v0.99.21...v0.99.23)

> 15 July 2021

- Added stationarypad, closes #47 [`#47`](https://github.com/RhetTbull/osxmetadata/issues/47)
- Added stationarypad to finderinfo [`f4db1bd`](https://github.com/RhetTbull/osxmetadata/commit/f4db1bd0eec063412552da2a0a0ebfcd8aa538d7)

#### [v0.99.21](https://github.com/RhetTbull/osxmetadata/compare/v0.99.19...v0.99.21)

> 14 July 2021

- Added findercolor [`f1cdf8c`](https://github.com/RhetTbull/osxmetadata/commit/f1cdf8c7a0b8ee0cbdeab58dadc53cd4eaddf725)
- Refactored FinderInfo code [`4b313a4`](https://github.com/RhetTbull/osxmetadata/commit/4b313a4de8a5104158aee6f3ac8839d8507e4913)
- Initial implementation for findercolor [`07b1082`](https://github.com/RhetTbull/osxmetadata/commit/07b10828a9f643245bc2e84223f62108b0f6ff6b)

#### [v0.99.19](https://github.com/RhetTbull/osxmetadata/compare/v0.99.18...v0.99.19)

> 8 July 2021

- Added kMDItemFSIsStationery, #18 [`4db1819`](https://github.com/RhetTbull/osxmetadata/commit/4db1819340612baf5ee985d73a0b1a0a30378507)
- Added kMDItemVersion, #18 [`ff09509`](https://github.com/RhetTbull/osxmetadata/commit/ff095094ca49a7524d82b64b03462cefe335cec7)
- Added kMDItemParticipants, #18 [`a71d207`](https://github.com/RhetTbull/osxmetadata/commit/a71d207a0ad5e8965bb9b1435ff8f2c4c21f6277)

#### [v0.99.18](https://github.com/RhetTbull/osxmetadata/compare/v0.99.15...v0.99.18)

> 8 July 2021

- docs: add bglezseoane as a contributor for code [`#42`](https://github.com/RhetTbull/osxmetadata/pull/42)
- Added kMDItemStarRating, #18 [`ad4af49`](https://github.com/RhetTbull/osxmetadata/commit/ad4af496d34227ef7c3f0f03c04f5a25d1cf1423)
- Added kMDItemDueDate, partial for #18 [`ec62337`](https://github.com/RhetTbull/osxmetadata/commit/ec623371e0c7b6576a92cb926a4552f868b13e26)
- Refactored code with sourcery [`8983ecb`](https://github.com/RhetTbull/osxmetadata/commit/8983ecb9cf72150017cbedafacaaf9d7e08ff432)
- Code cleanup [`5502716`](https://github.com/RhetTbull/osxmetadata/commit/5502716b39a89746405bf6b32159f7791ec266ea)
- docs: create .all-contributorsrc [skip ci] [`3fb69cf`](https://github.com/RhetTbull/osxmetadata/commit/3fb69cf2d46eca31bd4c5647b324064b6f30f63f)

#### [v0.99.15](https://github.com/RhetTbull/osxmetadata/compare/v0.99.14...v0.99.15)

> 5 July 2021

- Implemented --all for backup/restore, #33 [`31cc7fc`](https://github.com/RhetTbull/osxmetadata/commit/31cc7fc65cc95b296023159240aa4d0022ddeb43)
- Implemented --all for backup/restore, #33 [`a651efb`](https://github.com/RhetTbull/osxmetadata/commit/a651efb22785d5291d2dc8050ef4b40ce6c8a7b1)

#### [v0.99.14](https://github.com/RhetTbull/osxmetadata/compare/v0.99.13...v0.99.14)

> 5 June 2021

- Bump py from 1.8.1 to 1.10.0 [`#39`](https://github.com/RhetTbull/osxmetadata/pull/39)
- Bump pygments from 2.4.2 to 2.7.4 [`#38`](https://github.com/RhetTbull/osxmetadata/pull/38)
- Updated dependencies to minimize pyobjc requirements [`ddb468f`](https://github.com/RhetTbull/osxmetadata/commit/ddb468feee8f2fa72f08339f9d83e12d4aec527f)
- Added wheel and twine [`b5c4782`](https://github.com/RhetTbull/osxmetadata/commit/b5c478234258e74a6e2dfd8726c4d35c588f437c)

#### [v0.99.13](https://github.com/RhetTbull/osxmetadata/compare/v0.99.11...v0.99.13)

> 31 December 2020

- Removed logging.debug code, closes #36 [`#36`](https://github.com/RhetTbull/osxmetadata/issues/36)
- Bug fix for Finder comments extended attribute [`477c64e`](https://github.com/RhetTbull/osxmetadata/commit/477c64e649dc8dcb39faf87877d73b4ccb952b9e)
- Removed logging.debug code [`a20cfa1`](https://github.com/RhetTbull/osxmetadata/commit/a20cfa156e16182be427f2b7f4abad9f733fb24e)

#### [v0.99.11](https://github.com/RhetTbull/osxmetadata/compare/v0.99.10...v0.99.11)

> 18 December 2020

- Added tests for datetime_utils [`c1a2b62`](https://github.com/RhetTbull/osxmetadata/commit/c1a2b62e8084fc1ce5f1024453806868f5cc8e39)
- Added docstrings to datetime_utils [`c0b332d`](https://github.com/RhetTbull/osxmetadata/commit/c0b332d4305b6147c39a31853a2bac0931190ecd)
- Version bump [`fbe4d59`](https://github.com/RhetTbull/osxmetadata/commit/fbe4d596343f9ed1417f2f319f2b9300bacbfa80)

#### [v0.99.10](https://github.com/RhetTbull/osxmetadata/compare/v0.99.9...v0.99.10)

> 1 September 2020

- Fixed bug in datetime_utils, closes #34 [`#34`](https://github.com/RhetTbull/osxmetadata/issues/34)
- Updated README, added test for multiple --pattern [`3fb54ce`](https://github.com/RhetTbull/osxmetadata/commit/3fb54cee3c3e7f8b8bdd244c1afc197fe7eaafaf)

#### [v0.99.9](https://github.com/RhetTbull/osxmetadata/compare/v0.99.8...v0.99.9)

> 11 July 2020

- Added --pattern to CLI, closes #30 [`#30`](https://github.com/RhetTbull/osxmetadata/issues/30)

#### [v0.99.8](https://github.com/RhetTbull/osxmetadata/compare/v0.99.6...v0.99.8)

> 11 July 2020

- Refactored file processing in CLI [`f80922f`](https://github.com/RhetTbull/osxmetadata/commit/f80922f27c4dcedeee4202886231b69f47c24aa7)
- Added --files-only option to CLI [`8192816`](https://github.com/RhetTbull/osxmetadata/commit/8192816c9c2ce4b7505d4c492f45fcfc624a4dee)
- Added cli.py for use with pyinstaller [`bc754c7`](https://github.com/RhetTbull/osxmetadata/commit/bc754c7cc2a2253495db1fc7f55dc47768a607c5)

#### [v0.99.6](https://github.com/RhetTbull/osxmetadata/compare/v0.99.4...v0.99.6)

> 10 July 2020

- Added support for directories, closes #26, #27, #32 [`#26`](https://github.com/RhetTbull/osxmetadata/issues/26)
- Minor refactorings [`bf02536`](https://github.com/RhetTbull/osxmetadata/commit/bf02536212dd33c576a2c9ac0e4b0465d02cd8a4)

#### [v0.99.4](https://github.com/RhetTbull/osxmetadata/compare/v0.99.2...v0.99.4)

> 5 June 2020

- Fix issue #26 [`#29`](https://github.com/RhetTbull/osxmetadata/pull/29)
- Bug fix to address issue #28, partial fix [`b424398`](https://github.com/RhetTbull/osxmetadata/commit/b424398d65cad2d25e8145bb9dd7f772920e92a8)
- Fix directory exclusions when check existence [`e96d630`](https://github.com/RhetTbull/osxmetadata/commit/e96d63045a3cafc7bc1fedf23aa3581430095431)
- Write a simple test to the last commit [`9890e74`](https://github.com/RhetTbull/osxmetadata/commit/9890e74f4674712fd047547db5228e71037fcd09)
- Version bump [`1135473`](https://github.com/RhetTbull/osxmetadata/commit/113547385bfe5cab564ea9ec0be16db464ed9a69)

#### [v0.99.2](https://github.com/RhetTbull/osxmetadata/compare/v0.99.1...v0.99.2)

> 3 May 2020

- Bug fixed for broken directory support [`37abc74`](https://github.com/RhetTbull/osxmetadata/commit/37abc74de2d0c209b72663e5e82269c9e15228a1)

#### [v0.99.1](https://github.com/RhetTbull/osxmetadata/compare/v0.98.15...v0.99.1)

> 2 May 2020

- Major rewrite to add Tag object with support for Finder colors [`456490d`](https://github.com/RhetTbull/osxmetadata/commit/456490d5c2c9072b1458f0e0811622e9c56c4b96)
- refactored utils to break out functions into separate modules [`cc3eda7`](https://github.com/RhetTbull/osxmetadata/commit/cc3eda726d5d0c0e3103330d5d747fcaa8db68fb)
- Updated setup.py [`fcd3d2e`](https://github.com/RhetTbull/osxmetadata/commit/fcd3d2e5b84bef5367ae8117a2579d5fd331f245)

#### [v0.98.15](https://github.com/RhetTbull/osxmetadata/compare/v0.98.11...v0.98.15)

> 15 April 2020

- Fixed handling of datetime attributes, closes #17 [`#17`](https://github.com/RhetTbull/osxmetadata/issues/17)
- Updated README.md [`fd2888a`](https://github.com/RhetTbull/osxmetadata/commit/fd2888a2a8bc3046e49687b2c948d3ab79b358a9)
- Version bump [`609947c`](https://github.com/RhetTbull/osxmetadata/commit/609947c1651002f8f1d86e7756307b2c60d5a03d)
- Updated help text [`c3005b8`](https://github.com/RhetTbull/osxmetadata/commit/c3005b8cc4b8a6570040a0d7bcf460aad8e80098)
- Updated README [`5380240`](https://github.com/RhetTbull/osxmetadata/commit/53802409ee016449cdaa061478065116033bf0ed)

#### [v0.98.11](https://github.com/RhetTbull/osxmetadata/compare/v0.98.9...v0.98.11)

> 7 March 2020

- Added --copyfrom to CLI, closes #16 [`#16`](https://github.com/RhetTbull/osxmetadata/issues/16)
- Added short options to CLI [`09ecd5c`](https://github.com/RhetTbull/osxmetadata/commit/09ecd5c6fc9cc772f80538db85f101d52af0d7c4)
- Fixed verbose for --wipe and added test for --verbose [`3d03d1f`](https://github.com/RhetTbull/osxmetadata/commit/3d03d1f942fabdb1f237dfd3ac5531e31fa85a92)
- Added test for --version [`10e73c4`](https://github.com/RhetTbull/osxmetadata/commit/10e73c4ae9668444f0e7408dbce22c2a52587a94)
- Added utils [`336db4e`](https://github.com/RhetTbull/osxmetadata/commit/336db4ee9355e1793c9e8f10188cbcb702eeae74)
- Updated requirements.txt [`308d2f6`](https://github.com/RhetTbull/osxmetadata/commit/308d2f69f8cef60d644d65ee8f9fd6862ef69dae)

#### [v0.98.9](https://github.com/RhetTbull/osxmetadata/compare/v0.98.8...v0.98.9)

> 1 March 2020

- Added --wipe option to CLI; fixed order of restore/backup in CLI [`0ab4f33`](https://github.com/RhetTbull/osxmetadata/commit/0ab4f33555d46c4a3bb27ae3cc3e5d3ad0f82d89)

#### [v0.98.8](https://github.com/RhetTbull/osxmetadata/compare/v0.98.7...v0.98.8)

> 1 March 2020

- Added --mirror to CLI [`b50d309`](https://github.com/RhetTbull/osxmetadata/commit/b50d3098bcc6bdb9dedc85bf792701d600ed90df)

#### [v0.98.7](https://github.com/RhetTbull/osxmetadata/compare/v0.98.5...v0.98.7)

> 1 March 2020

- Added backup/restore to CLI [`cd9b52e`](https://github.com/RhetTbull/osxmetadata/commit/cd9b52e9b3d6d78ecd10d705025ea03671ebe3a5)

#### [v0.98.5](https://github.com/RhetTbull/osxmetadata/compare/v0.98.1...v0.98.5)

> 29 February 2020

- Major refactor to move tags to a list instead of a set, added tests, closes #15 [`#15`](https://github.com/RhetTbull/osxmetadata/issues/15)
- Added --json to CLI [`d4f9906`](https://github.com/RhetTbull/osxmetadata/commit/d4f9906d61259769af56385bb5940dfcd49b089d)
- Fixed set behavior for tags [`056abf5`](https://github.com/RhetTbull/osxmetadata/commit/056abf508a12eadf0b4fd17f8a8de07bcf293d6c)
- Updated README.md [`e391188`](https://github.com/RhetTbull/osxmetadata/commit/e391188986a51329a67559c2b680b384a850942f)
- Updated README.md [`b6a8872`](https://github.com/RhetTbull/osxmetadata/commit/b6a8872e801c44e95043a9bc77941993708d94a4)
- Updated README.md [`8d9985c`](https://github.com/RhetTbull/osxmetadata/commit/8d9985cc267c2bbbc4d1b5acf1928759df67c179)

#### [v0.98.1](https://github.com/RhetTbull/osxmetadata/compare/v0.98.0...v0.98.1)

> 23 February 2020

#### [v0.98.0](https://github.com/RhetTbull/osxmetadata/compare/v0.96.87...v0.98.0)

> 23 February 2020

- tests passed! [`6466adf`](https://github.com/RhetTbull/osxmetadata/commit/6466adfc5f75023a96bbc36de236e84d68eb4207)
- Added tests [`0cfb309`](https://github.com/RhetTbull/osxmetadata/commit/0cfb309ac2dc0b902cac878b1b6b1ab1556d1346)
- Got --set working in new rewrite [`9ebc6d4`](https://github.com/RhetTbull/osxmetadata/commit/9ebc6d47d65d58fd8e97978d33908bc6f99b2e6a)

#### [v0.96.87](https://github.com/RhetTbull/osxmetadata/compare/v0.96.83...v0.96.87)

> 1 August 2019

- Re-applied __version__ to match PEP 396 [`6e27a8a`](https://github.com/RhetTbull/osxmetadata/commit/6e27a8a0adda8cae6d00a06ff708ae3609062a49)
- Change __version__ to _version_ to be PEP8 compliant [`df89ccb`](https://github.com/RhetTbull/osxmetadata/commit/df89ccbeb9a3189ecbc0f799ca5678e6a75e750c)
- Removed osxmetadat.version from setup.py [`7113821`](https://github.com/RhetTbull/osxmetadata/commit/711382115caeb8245b68f8b47158daebfd085098)

#### [v0.96.83](https://github.com/RhetTbull/osxmetadata/compare/v0.96.5...v0.96.83)

> 28 July 2019

- Added --version to cmd_line [`3e33b31`](https://github.com/RhetTbull/osxmetadata/commit/3e33b315752f8d9a8afff45c3a831c44491040e5)
- Added some docstrings [`61be4b5`](https://github.com/RhetTbull/osxmetadata/commit/61be4b5c5ecb9274a33dfd8d1f896ecdad0ca54b)
- Added version to cmd_line [`ebd6091`](https://github.com/RhetTbull/osxmetadata/commit/ebd60919fb6e3e7ca5ae7f8bb6c6d0e10779f5fa)

#### v0.96.5

> 27 July 2019

- Create LICENSE [`#1`](https://github.com/RhetTbull/osxmetadata/pull/1)
- Ran black on all code [`1b1384d`](https://github.com/RhetTbull/osxmetadata/commit/1b1384d5d1a06b0ca237a37b58431b650f876934)
- Added package folder [`a88aad7`](https://github.com/RhetTbull/osxmetadata/commit/a88aad75e2fe8197d869ebb9b483bb9758beef92)
- Moving code into module and added unittests [`23ac288`](https://github.com/RhetTbull/osxmetadata/commit/23ac288888312375a882221031076203b8e48180)
- removed osxmetadata.py to move to package [`2a5530b`](https://github.com/RhetTbull/osxmetadata/commit/2a5530bc6540956706a50a8e708faae56a66ea19)
- removed loguru debug code [`54a4cb4`](https://github.com/RhetTbull/osxmetadata/commit/54a4cb4cd7e33e22548f666c96487912952b7fa6)
